# af_licence_manager
No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- Package version: 2.0.1
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import af_licence_manager 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import af_licence_manager
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import af_licence_manager
from af_licence_manager.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = af_licence_manager.AristaFlowServiceApi(af_licence_manager.ApiClient(configuration))

try:
    api_response = api_instance.get_release()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AristaFlowServiceApi->get_release: %s\n" % e)

# create an instance of the API class
api_instance = af_licence_manager.AristaFlowServiceApi(af_licence_manager.ApiClient(configuration))

try:
    api_response = api_instance.get_service_instance_name()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AristaFlowServiceApi->get_service_instance_name: %s\n" % e)

# create an instance of the API class
api_instance = af_licence_manager.AristaFlowServiceApi(af_licence_manager.ApiClient(configuration))

try:
    api_response = api_instance.get_uris()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AristaFlowServiceApi->get_uris: %s\n" % e)

# create an instance of the API class
api_instance = af_licence_manager.AristaFlowServiceApi(af_licence_manager.ApiClient(configuration))

try:
    api_response = api_instance.ping()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AristaFlowServiceApi->ping: %s\n" % e)

# create an instance of the API class
api_instance = af_licence_manager.AristaFlowServiceApi(af_licence_manager.ApiClient(configuration))

try:
    api_instance.register_sse()
except ApiException as e:
    print("Exception when calling AristaFlowServiceApi->register_sse: %s\n" % e)

# create an instance of the API class
api_instance = af_licence_manager.AristaFlowServiceApi(af_licence_manager.ApiClient(configuration))
sse_id = '38400000-8cf0-11bd-b23e-10b96e4ef00d' # str | 

try:
    api_response = api_instance.unregister_sse(sse_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AristaFlowServiceApi->unregister_sse: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to */*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AristaFlowServiceApi* | [**get_release**](docs/AristaFlowServiceApi.md#get_release) | **GET** /release | 
*AristaFlowServiceApi* | [**get_service_instance_name**](docs/AristaFlowServiceApi.md#get_service_instance_name) | **GET** /service-instance-name | 
*AristaFlowServiceApi* | [**get_uris**](docs/AristaFlowServiceApi.md#get_uris) | **GET** /uris | 
*AristaFlowServiceApi* | [**ping**](docs/AristaFlowServiceApi.md#ping) | **GET** /start-time | 
*AristaFlowServiceApi* | [**register_sse**](docs/AristaFlowServiceApi.md#register_sse) | **GET** /sse | 
*AristaFlowServiceApi* | [**unregister_sse**](docs/AristaFlowServiceApi.md#unregister_sse) | **DELETE** /sse/{sseId} | 
*LicenceManagerApi* | [**get_licence_information**](docs/LicenceManagerApi.md#get_licence_information) | **GET** /licence | 
*DefaultApi* | [**header_data**](docs/DefaultApi.md#header_data) | **GET** /header-data | 

## Documentation For Models

 - [AbortServiceException](docs/AbortServiceException.md)
 - [AbortTransactionException](docs/AbortTransactionException.md)
 - [AgentUnknownException](docs/AgentUnknownException.md)
 - [AuthenticationException](docs/AuthenticationException.md)
 - [ConfigurationException](docs/ConfigurationException.md)
 - [DataConsistencyException](docs/DataConsistencyException.md)
 - [DataSourceException](docs/DataSourceException.md)
 - [DummyParent](docs/DummyParent.md)
 - [EbpInstanceReference](docs/EbpInstanceReference.md)
 - [IlmException](docs/IlmException.md)
 - [IlmExceptionCause](docs/IlmExceptionCause.md)
 - [IlmExceptionStackTrace](docs/IlmExceptionStackTrace.md)
 - [IlmExceptionSuppressed](docs/IlmExceptionSuppressed.md)
 - [IncompatibleGuiContextException](docs/IncompatibleGuiContextException.md)
 - [InterruptException](docs/InterruptException.md)
 - [InvalidActivityStateException](docs/InvalidActivityStateException.md)
 - [InvalidDataContainerException](docs/InvalidDataContainerException.md)
 - [InvalidInstanceStateException](docs/InvalidInstanceStateException.md)
 - [InvalidTemplateStateException](docs/InvalidTemplateStateException.md)
 - [LicenceInformation](docs/LicenceInformation.md)
 - [LockException](docs/LockException.md)
 - [OrgModelException](docs/OrgModelException.md)
 - [ParameterException](docs/ParameterException.md)
 - [ParameterMissingException](docs/ParameterMissingException.md)
 - [ParameterTypeException](docs/ParameterTypeException.md)
 - [PasswordPolicyException](docs/PasswordPolicyException.md)
 - [PlainTextException](docs/PlainTextException.md)
 - [PolicyResolutionException](docs/PolicyResolutionException.md)
 - [QualifiedAgent](docs/QualifiedAgent.md)
 - [ScriptEnvironmentException](docs/ScriptEnvironmentException.md)
 - [ScriptEvaluationException](docs/ScriptEvaluationException.md)
 - [ScriptException](docs/ScriptException.md)
 - [ServiceInstanceName](docs/ServiceInstanceName.md)
 - [ServiceNotKnownException](docs/ServiceNotKnownException.md)
 - [ServiceRelease](docs/ServiceRelease.md)
 - [Session](docs/Session.md)
 - [SessionToken](docs/SessionToken.md)
 - [UnknownSessionException](docs/UnknownSessionException.md)
 - [WrappingException](docs/WrappingException.md)
 - [WrongAgentException](docs/WrongAgentException.md)
 - [WrongRuntimeManagerException](docs/WrongRuntimeManagerException.md)

## Documentation For Authorization

 All endpoints do not require authorization.


## Author


